"use strict";
(function () {
    let timer = null;
    let timerType = "Timeout";
    let timeLeft = 0;
    
    window.onload = function () {
        let timerTypes = document.getElementsByName("timer-type");
        for (let i = 0; i < timerTypes.length; i++) {
            timerTypes[i].onchange = changeTimer;
        }
        document.getElementById("start-timer").onclick = startTimer;
        document.getElementById("clear-interval").onclick = stopTimer;
        document.getElementById("inmillis").oninput = fillInputSecs;
        fillDesc();
    };
    
    function fillDesc() {
        let elem = document.getElementById("description");
        if (timerType == "Timeout") {
            elem.innerHTML = "setTimeout runs the function once after the specified time"
        } else {
            elem.innerHTML = "setInterval nonstop calls the function with the specified delay"
        }
    }
    
    function fillInputSecs() {
        let value = this.value;
        document.getElementById("insecs").value = value / 1000;
        document.getElementById("codedisplay-timeout").innerHTML = value;
    }
    
    function startTimer() {
        document.getElementById("start-fieldset").classList.add("hidden");
        timeLeft = document.getElementById("inmillis").value;
        disableForms(true);
        timer = setTimeout(tickTimer, 100);
    }
    
    function shakeTimer() {
        let timerElem = document.getElementById("timer");
        timerElem.classList.add("shake-hard");
        timerElem.classList.add("shake-constant");
        setTimeout(stopShake, 800);
    }
    
    function stopShake() {
        let timerElem = document.getElementById("timer");
        timerElem.classList.remove("shake-hard");
        timerElem.classList.remove("shake-constant");
    }
    
    function tickTimer() {
        displayTimer();
        if (timeLeft > 0) {
            timeLeft-=100;
            if (timeLeft < 0) {
                timeLeft = 0;
            }
            timer = setTimeout(tickTimer, 100);
            return;
        }
        if (timerType == "Timeout") {
            stopTimer();
        } else {
            startTimer();
        }
        shakeTimer();
    }
    
    function displayTimer() {
        let secs = Math.trunc(timeLeft / 1000);
        let millis = Math.trunc((timeLeft / 1000 % 1) * 10);
        document.getElementById("secs").innerHTML = secs;
        document.getElementById("millis").innerHTML = millis;
    }
    
    function stopTimer() {
        document.getElementById("start-fieldset").classList.remove("hidden");
        disableForms(false);
        clearTimeout(timer);
    }
    
    function changeTimer() {
        timerType = this.value;
        fillDesc();
        document.getElementById("codedisplay-type").innerHTML = timerType;
        
        if (timerType === "Interval") {
            document.getElementById("clearinterval-fieldset").classList.remove("hidden");
        } else {
            document.getElementById("clearinterval-fieldset").classList.add("hidden");
        }
    }
    
    function disableForms(disabled) {
        let inputs = document.getElementsByTagName("input");
        for (let i = 0; i < inputs.length; i++) {
            inputs[i].disabled = disabled;
        }
        document.getElementById("clear-interval").disabled = false;
        document.getElementById("start-timer").disabled = false;
    }
})();